@@ -1,4 +1,4 @@
-package Pcore::SMTP v0.5.2;
+package Pcore::SMTP v0.5.3;
 
 use Pcore -dist, -const, -class, -result;
 use Pcore::AE::Handle qw[:TLS_CTX];
@@ -639,6 +639,10 @@ AnyEvent based SMTP protocol implementation.
 
 =head1 METHODS
 
+=head2 new(\%args)
+
+Please, see L</SYNOPSIS>
+
 =head2 sendmail(%args)
 
 Where %args are:
